function [ x, y ] = arm_thetas_to_xy( theta1, theta2 )
%ARM_THETAS_TO_XY Uses forward kinematics to give position from angle
%   Pass in theta1 and theta2 (in degrees)
%   Returns x and y
%   ---
%   Sam Bobb,  Daniel Cornew,  Ryan Deeter
%   Ben Tollberg
%	Two degree of freedom arm
%	Pantograph Robot Motor Control
%	Code version 4
%	June 10, 2010
%   ---

% pull in constants
arm_constants

theta = theta1*(pi/180);
alpha = theta2*(pi/180);

x2 = L1 * cos(theta);
y2 = L1 * sin(theta);

y4 = L4 * sin(alpha);
x4 = L4 * cos(alpha) - L5;

two_to_four = sqrt((x2-x4).^2 + (y2-y4).^2);

two_to_h = (L2^2 - L3^2 + two_to_four.^2) ./ (2 * two_to_four);

yh = y2 + (two_to_h./two_to_four).*(y4-y2);
xh = x2 + (two_to_h./two_to_four).*(x4-x2);

three_to_h = sqrt(L2^2 - two_to_h.^2);

x = xh + (three_to_h./two_to_four) .* (y4-y2);
y = yh - (three_to_h./two_to_four) .* (x4-x2);

end

