function [ theta1, theta2 ] = arm_xy_to_thetas( x, y )
%ARM_XY_TO_THETAS Uses inversion kinematics to give angles for position
%   Pass in x and y
%   Returns theta1 and theta2 (in degrees)
%   ---
%   Sam Bobb,  Daniel Cornew,  Ryan Deeter
%   Ben Tollberg
%	Two degree of freedom arm
%	Pantograph Robot Motor Control
%	Code version 4
%	June 10, 2010
%   ---

% pull in constants
arm_constants

% calculate the theta path      
L13 = sqrt(x.^2+y.^2);
L53 = sqrt((x+L5).^2 + y.^2);

alphaOne = acos((L1.^2 + L13.^2 - L2.^2)./(2.*L1.*L13));
betaOne = atan2(y,-x);
thetaOne = pi - alphaOne - betaOne;

alphaFive = atan2(y,x+L5);
betaFive = acos((L53.^2 + L4.^2 - L3.^2)./(2.*L53.*L4));
thetaFive = alphaFive + betaFive;

% convert to degrees
theta1 = 180*(thetaOne/pi);
theta2 = 180*(thetaFive/pi);

end

